@@ -1,5 +1,5 @@
 package Positron::DataTemplate;
-our $VERSION = 'v0.0.4'; # VERSION
+our $VERSION = 'v0.0.5'; # VERSION
 
 =head1 NAME
 
@@ -7,7 +7,7 @@ Positron::DataTemplate - templating plain data to plain data
 
 =head1 VERSION
 
-version v0.0.4
+version v0.0.5
 
 =head1 SYNOPSIS
 
@@ -109,6 +109,16 @@ give some examples.
   [1, '^len', "abcde", 2] + { len => \&CORE::length }
   -> [1, 5, 2]
 
+=head2 Assignment
+
+  [1, '= title object.name', 'My {$title} and {$count}' ]
+  + { object => { name => 'Name', count => 10 } }
+  -> [1, 'My Name and']
+
+=head2 Escaping other constructs
+
+  [ '~?cond', 'Talking about {{~}$templates}', '~.htaccess' ]
+  -> [ '?cond', 'Talking about {$templates}', '.htaccess' ]
 =cut
 
 use v5.10;
@@ -172,9 +182,14 @@ sub _process_text {
             return (Positron::Expression::evaluate($expr, $env), $interpolate);
         }
     } elsif ($template =~ m{ \A \$ (.*) \z}xms) {
-        return ("" . Positron::Expression::evaluate($1, $env), 0);
+        my $value = Positron::Expression::evaluate($1, $env) // '';
+        return ("$value", 0);
     } elsif ($template =~ m{ \A \x23 (\+?) }xms) {
         return ('', ($1 ? 0 : 1));
+    } elsif ($template =~ m{ \A = \s* (\w+) \s+ (.*) }xms) {
+        # Always interpolates, the new identifier means nothing
+        Positron::Expression::evaluate($2, $env); # still perform it, means nothing
+        return ('', 1);
     } elsif ($template =~ m{ \A ([.:]) (-?) \s* ([^\s-].*) }xms) {
         my $filename_expr = $3;
         if ($2) { $interpolate = 1; }
@@ -224,6 +239,9 @@ sub _process_text {
         }{
             $2 ? '' : $1 . $4;
         }xmseg;
+        # At the very end: get rid of escaping tildes (one layer)
+        $template =~ s{ \A ~ }{}xms;
+        $template =~ s{ \{ ~ \} }{}xmsg;
         return ($template, 0);
     }
 }
@@ -289,6 +307,8 @@ sub _process_array {
             } elsif ($element =~ m{ \A / (-?) }xms) {
                 if ($is_first_element and $1) { $interpolate = 1; }
                 $skip_next = 1;
+            } elsif ($skip_next) {
+                $skip_next = 0;
             } elsif ($element =~ m{ \A \^ (-?) \s* ([^\s-].*) }xms) {
                 if ($is_first_element and $1) { $interpolate = 1; }
                 $capturing_function = Positron::Expression::evaluate($2, $env);
@@ -315,8 +335,13 @@ sub _process_array {
                     croak "Can't find template '$filename' in " . join(':', @{$self->{include_paths}});
                 }
                 # do not push!
-            } elsif ($skip_next) {
-                $skip_next = 0;
+            } elsif ($element =~ m{ \A = (-?) \s* (\w+) \s+ (.*) }xms) {
+                if ($is_first_element and $1) { $interpolate = 1; }
+                my $new_key = $2;
+                my $new_value = Positron::Expression::evaluate($3, $env);
+                # We change env here!
+                $env = Positron::Environment->new({}, { parent => $env });
+                $env->set($new_key, $new_value); # Handles '_' on either side
             } elsif ($capturing_function) {
                 # we have a capturing function waiting for input
                 my ($arg, $i) = $self->_process($element, $env);
@@ -501,6 +526,20 @@ sub _process_hash {
                 }
                 next;
             }
+            if ($key =~ m{ \A = (-?) \s* (\w+) \s+ (.*) }xms) {
+                # assignment (always interpolates)
+                my $new_key = $2;
+                my $new_value = Positron::Expression::evaluate($3, $env);
+                # We change env here!
+                my $new_env = Positron::Environment->new({}, { parent => $env });
+                $new_env->set($new_key, $new_value); # Handles '_' on either side
+                my ($hash_out, undef) = $self->_process($value, $new_env);
+                # interpolate
+                foreach my $k (keys %$hash_out) {
+                    $result{$k} = $hash_out->{$k};
+                }
+                next;
+            }
             ($key, undef) = $self->_process($key, $env);
             ($value, undef) = $self->_process($value, $env);
             $result{$key} = $value;
